.. Transonic documentation master file

.. include:: ../README.rst

Backends
--------

.. toctree::
   :maxdepth: 2

   pythran_backend
   other_backends

Examples
--------

.. toctree::
   :maxdepth: 2

   examples/classic
   examples/type_hints
   examples/using_jit
   examples/blocks
   examples/methods
   ipynb/executed/demo_compile_at_import
   ipynb/executed/demo_jit

Modules Reference
-----------------

Here is presented the general organization of the package and the documentation
of the modules, classes and functions.

.. autosummary::
   :toctree: generated/

    transonic.aheadoftime
    transonic.transpiler
    transonic.annotation
    transonic.justintime
    transonic.pythranizer
    transonic.dist
    transonic.run
    transonic.log
    transonic.util
    transonic.config

More
----

.. toctree::
   :maxdepth: 1

   Transonic forge on Bitbucket <https://bitbucket.org/fluiddyn/transonic>
   Transonic in PyPI  <https://pypi.python.org/pypi/transonic/>
   changes
   authors
   for_dev


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
